import { AbstractPowerSyncDatabase, Transaction } from '@journeyapps/powersync-sdk-common';
import { AttachmentRecord } from './Schema';
import { StorageAdapter } from './StorageAdapter';
export interface AttachmentQueueOptions {
    powersync: AbstractPowerSyncDatabase;
    storage: StorageAdapter;
    /**
     * How often to check for new attachments to sync, in milliseconds. Set to 0 or undefined to disable.
     */
    syncInterval?: number;
    /**
     * How many attachments to keep in the cache
     */
    cacheLimit?: number;
    /**
     * The name of the directory where attachments are stored on the device, not the full path
     */
    attachmentDirectoryName?: string;
    /**
     * Whether to mark the initial watched attachment IDs to be synced
     */
    performInitialSync?: boolean;
}
export declare const DEFAULT_ATTACHMENT_QUEUE_OPTIONS: Partial<AttachmentQueueOptions>;
export declare abstract class AbstractAttachmentQueue<T extends AttachmentQueueOptions = AttachmentQueueOptions> {
    uploading: boolean;
    downloading: boolean;
    initialSync: boolean;
    options: T;
    downloadQueue: Set<string>;
    constructor(options: T);
    /**
     * Returns an async iterator that yields attachment IDs that need to be synced.
     * In most cases this will be a watch query
     *
     * Example:
     * for await (const result of powersync.watch('SELECT photo_id as id FROM todos WHERE photo_id IS NOT NULL', [])) {
     *    yield result.rows?._array.map((r) => r.id) ?? [];
     * }
     */
    abstract attachmentIds(): AsyncIterable<string[]>;
    /**
     * Create a new AttachmentRecord, this gets called when the attachment id is not found in the database.
     */
    abstract newAttachmentRecord(record?: Partial<AttachmentRecord>): Promise<AttachmentRecord>;
    protected get powersync(): AbstractPowerSyncDatabase;
    protected get storage(): StorageAdapter;
    get table(): string;
    get storageDirectory(): string;
    init(): Promise<void>;
    trigger(): void;
    watchAttachmentIds(): Promise<void>;
    saveToQueue(record: Omit<AttachmentRecord, 'timestamp'>): Promise<AttachmentRecord>;
    record(id: string): Promise<AttachmentRecord | null>;
    update(record: Omit<AttachmentRecord, 'timestamp'>): Promise<void>;
    delete(record: AttachmentRecord, tx?: Transaction): Promise<void>;
    getNextUploadRecord(): Promise<AttachmentRecord | null>;
    uploadAttachment(record: AttachmentRecord): Promise<boolean>;
    downloadRecord(record: AttachmentRecord): Promise<boolean>;
    idsToUpload(): AsyncIterable<string[]>;
    watchUploads(): Promise<void>;
    /**
     * Returns immediately if another loop is in progress.
     */
    private uploadRecords;
    getIdsToDownload(): Promise<string[]>;
    idsToDownload(): AsyncIterable<string[]>;
    watchDownloads(): Promise<void>;
    private downloadRecords;
    getLocalUri(filename: string): string;
    expireCache(): Promise<void>;
    clearQueue(): Promise<void>;
}
